Remove empty sections from Robot Framework files. A section
(like `*** Test Cases ***`, `*** Keywords ***`, etc.) should not be declared if it
contains no content.

Fix automatically by removing the empty section header. Continue without asking.
